@@ -17,11 +17,13 @@ type AGEEncryption struct {
 	Args            []string
 	Identity        string
 	Identities      []string
+	Passphrase      bool
 	Recipient       string
 	Recipients      []string
 	RecipientsFile  AbsPath
 	RecipientsFiles []AbsPath
 	Suffix          string
+	Symmetric       bool
 }
 
 // Decrypt implements Encyrption.Decrypt.
@@ -74,8 +76,45 @@ func (e *AGEEncryption) EncryptedSuffix() string {
 
 // decryptArgs returns the arguments for decryption.
 func (e *AGEEncryption) decryptArgs() []string {
-	args := make([]string, 0, 1+2*(1+len(e.Identities)))
+	var args []string
 	args = append(args, "--decrypt")
+	if !e.Passphrase {
+		args = append(args, e.identityArgs()...)
+	}
+	return args
+}
+
+// encryptArgs returns the arguments for encryption.
+func (e *AGEEncryption) encryptArgs() []string {
+	var args []string
+	args = append(args,
+		"--armor",
+		"--encrypt",
+	)
+	switch {
+	case e.Passphrase:
+		args = append(args, "--passphrase")
+	case e.Symmetric:
+		args = append(args, e.identityArgs()...)
+	default:
+		if e.Recipient != "" {
+			args = append(args, "--recipient", e.Recipient)
+		}
+		for _, recipient := range e.Recipients {
+			args = append(args, "--recipient", recipient)
+		}
+		if e.RecipientsFile != "" {
+			args = append(args, "--recipients-file", string(e.RecipientsFile))
+		}
+		for _, recipientsFile := range e.RecipientsFiles {
+			args = append(args, "--recipients-file", string(recipientsFile))
+		}
+	}
+	return args
+}
+
+func (e *AGEEncryption) identityArgs() []string {
+	args := make([]string, 0, 2+2*len(e.Identities))
 	if e.Identity != "" {
 		args = append(args, "--identity", e.Identity)
 	}
@@ -84,22 +123,3 @@ func (e *AGEEncryption) decryptArgs() []string {
 	}
 	return args
 }
-
-// encryptArgs returns the arguments for encryption.
-func (e *AGEEncryption) encryptArgs() []string {
-	args := make([]string, 0, 1+2*(1+len(e.Recipients))+2*(1+len(e.RecipientsFiles)))
-	args = append(args, "--armor")
-	if e.Recipient != "" {
-		args = append(args, "--recipient", e.Recipient)
-	}
-	for _, recipient := range e.Recipients {
-		args = append(args, "--recipient", recipient)
-	}
-	if e.RecipientsFile != "" {
-		args = append(args, "--recipients-file", string(e.RecipientsFile))
-	}
-	for _, recipientsFile := range e.RecipientsFiles {
-		args = append(args, "--recipients-file", string(recipientsFile))
-	}
-	return args
-}
