@@ -23,6 +23,7 @@ import (
 	"github.com/Masterminds/sprig/v3"
 	"github.com/coreos/go-semver/semver"
 	"github.com/go-git/go-git/v5/plumbing/format/diff"
+	"github.com/google/gops/agent"
 	"github.com/mitchellh/mapstructure"
 	"github.com/rs/zerolog"
 	"github.com/rs/zerolog/log"
@@ -50,21 +51,23 @@ type templateConfig struct {
 // A Config represents a configuration.
 type Config struct {
 	// Global configuration, settable in the config file.
-	SourceDirAbsPath chezmoi.AbsPath        `mapstructure:"sourceDir"`
-	DestDirAbsPath   chezmoi.AbsPath        `mapstructure:"destDir"`
-	Umask            fs.FileMode            `mapstructure:"umask"`
-	Remove           bool                   `mapstructure:"remove"`
-	Color            *autoBool              `mapstructure:"color"`
-	Data             map[string]interface{} `mapstructure:"data"`
-	Template         templateConfig         `mapstructure:"template"`
-	UseBuiltinGit    *autoBool              `mapstructure:"useBuiltinGit"`
-	Pager            string                 `mapstructure:"pager"`
+	SourceDirAbsPath chezmoi.AbsPath                 `mapstructure:"sourceDir"`
+	DestDirAbsPath   chezmoi.AbsPath                 `mapstructure:"destDir"`
+	Umask            fs.FileMode                     `mapstructure:"umask"`
+	Remove           bool                            `mapstructure:"remove"`
+	Color            *autoBool                       `mapstructure:"color"`
+	Data             map[string]interface{}          `mapstructure:"data"`
+	Template         templateConfig                  `mapstructure:"template"`
+	UseBuiltinGit    *autoBool                       `mapstructure:"useBuiltinGit"`
+	Pager            string                          `mapstructure:"pager"`
+	Interpreters     map[string]*chezmoi.Interpreter `mapstructure:"interpreters"`
 
 	// Global configuration, not settable in the config file.
 	cpuProfile    chezmoi.AbsPath
 	debug         bool
 	dryRun        bool
 	force         bool
+	gops          bool
 	homeDir       string
 	keepGoing     bool
 	noPager       bool
@@ -198,11 +201,12 @@ func newConfig(options ...configOption) (*Config, error) {
 	}
 
 	c := &Config{
-		bds:        bds,
-		fileSystem: vfs.OSFS,
-		homeDir:    userHomeDir,
-		Umask:      chezmoi.Umask,
-		Pager:      os.Getenv("PAGER"),
+		bds:          bds,
+		fileSystem:   vfs.OSFS,
+		homeDir:      userHomeDir,
+		Umask:        chezmoi.Umask,
+		Pager:        os.Getenv("PAGER"),
+		Interpreters: defaultInterpreters,
 		Add: addCmdConfig{
 			exclude:   chezmoi.NewEntryTypeSet(chezmoi.EntryTypesNone),
 			include:   chezmoi.NewEntryTypeSet(chezmoi.EntryTypesAll),
@@ -958,11 +962,11 @@ func (c *Config) newRootCmd() (*cobra.Command, error) {
 
 	persistentFlags := rootCmd.PersistentFlags()
 
-	persistentFlags.Var(c.Color, "color", "colorize diffs")
-	persistentFlags.VarP(&c.DestDirAbsPath, "destination", "D", "destination directory")
-	persistentFlags.BoolVar(&c.Remove, "remove", c.Remove, "remove targets")
-	persistentFlags.VarP(&c.SourceDirAbsPath, "source", "S", "source directory")
-	persistentFlags.Var(c.UseBuiltinGit, "use-builtin-git", "use builtin git")
+	persistentFlags.Var(c.Color, "color", "Colorize output")
+	persistentFlags.VarP(&c.DestDirAbsPath, "destination", "D", "Set destination directory")
+	persistentFlags.BoolVar(&c.Remove, "remove", c.Remove, "Remove entries from destination directory")
+	persistentFlags.VarP(&c.SourceDirAbsPath, "source", "S", "Set source directory")
+	persistentFlags.Var(c.UseBuiltinGit, "use-builtin-git", "Use builtin git")
 	for _, key := range []string{
 		"color",
 		"destination",
@@ -974,22 +978,25 @@ func (c *Config) newRootCmd() (*cobra.Command, error) {
 		}
 	}
 
-	persistentFlags.VarP(&c.configFileAbsPath, "config", "c", "config file")
-	persistentFlags.Var(&c.cpuProfile, "cpu-profile", "write CPU profile")
-	persistentFlags.BoolVar(&c.debug, "debug", c.debug, "write debug logs")
-	persistentFlags.BoolVarP(&c.dryRun, "dry-run", "n", c.dryRun, "dry run")
-	persistentFlags.BoolVar(&c.force, "force", c.force, "force")
-	persistentFlags.BoolVarP(&c.keepGoing, "keep-going", "k", c.keepGoing, "keep going as far as possible after an error")
-	persistentFlags.BoolVar(&c.noPager, "no-pager", c.noPager, "do not use the pager")
-	persistentFlags.BoolVar(&c.noTTY, "no-tty", c.noTTY, "don't attempt to get a TTY for reading passwords")
-	persistentFlags.VarP(&c.outputAbsPath, "output", "o", "output file")
-	persistentFlags.BoolVar(&c.sourcePath, "source-path", c.sourcePath, "specify targets by source path")
-	persistentFlags.BoolVarP(&c.verbose, "verbose", "v", c.verbose, "verbose")
+	persistentFlags.VarP(&c.configFileAbsPath, "config", "c", "Set config file")
+	persistentFlags.Var(&c.cpuProfile, "cpu-profile", "Write a CPU profile to path")
+	persistentFlags.BoolVar(&c.debug, "debug", c.debug, "Include debug information in output")
+	persistentFlags.BoolVarP(&c.dryRun, "dry-run", "n", c.dryRun, "Do not make any modifications to the destination directory")
+	persistentFlags.BoolVar(&c.force, "force", c.force, "Make all changes without prompting")
+	persistentFlags.BoolVar(&c.gops, "gops", c.gops, "Enable gops agent")
+	persistentFlags.BoolVarP(&c.keepGoing, "keep-going", "k", c.keepGoing, "Keep going as far as possible after an error")
+	persistentFlags.BoolVar(&c.noPager, "no-pager", c.noPager, "Do not use the pager")
+	persistentFlags.BoolVar(&c.noTTY, "no-tty", c.noTTY, "Do not attempt to get a TTY for reading passwords")
+	persistentFlags.VarP(&c.outputAbsPath, "output", "o", "Write output to path instead of stdout")
+	persistentFlags.BoolVar(&c.sourcePath, "source-path", c.sourcePath, "Specify targets by source path")
+	persistentFlags.BoolVarP(&c.verbose, "verbose", "v", c.verbose, "Make output more verbose")
 
 	for _, err := range []error{
 		rootCmd.MarkPersistentFlagFilename("config"),
 		rootCmd.MarkPersistentFlagFilename("cpu-profile"),
+		persistentFlags.MarkHidden("cpu-profile"),
 		rootCmd.MarkPersistentFlagDirname("destination"),
+		persistentFlags.MarkHidden("gops"),
 		rootCmd.MarkPersistentFlagFilename("output"),
 		rootCmd.MarkPersistentFlagDirname("source"),
 	} {
@@ -1079,6 +1086,10 @@ func (c *Config) persistentPostRunRootE(cmd *cobra.Command, args []string) error
 		}
 	}
 
+	if c.gops {
+		agent.Close()
+	}
+
 	return nil
 }
 
@@ -1115,6 +1126,12 @@ func (c *Config) persistentPreRunRootE(cmd *cobra.Command, args []string) error
 		}
 	}
 
+	if c.gops {
+		if err := agent.Listen(agent.Options{}); err != nil {
+			return err
+		}
+	}
+
 	if err := c.readConfig(); err != nil {
 		if !boolAnnotation(cmd, doesNotRequireValidConfig) {
 			return fmt.Errorf("invalid config: %s: %w", c.configFileAbsPath, err)
@@ -1384,6 +1401,7 @@ func (c *Config) sourceState() (*chezmoi.SourceState, error) {
 		chezmoi.WithDefaultTemplateDataFunc(c.defaultTemplateData),
 		chezmoi.WithDestDir(c.DestDirAbsPath),
 		chezmoi.WithEncryption(c.encryption),
+		chezmoi.WithInterpreters(c.Interpreters),
 		chezmoi.WithPriorityTemplateData(c.Data),
 		chezmoi.WithSourceDir(c.SourceDirAbsPath),
 		chezmoi.WithSystem(c.sourceSystem),
